@@ -205,6 +205,8 @@ void audio_move_update(void *data, obs_data_t *settings)
 	if (source && obs_source_removed(source))
 		source = NULL;
 	obs_scene_t *scene = obs_scene_from_source(source);
+	if (!scene)
+		scene = obs_group_from_source(source);
 	if (audio_move->sceneitem) {
 		signal_handler_t *sh = obs_source_get_signal_handler(source);
 		if (sh) {
@@ -231,7 +233,7 @@ void audio_move_update(void *data, obs_data_t *settings)
 		}
 	}
 	audio_move->sceneitem =
-		scene ? obs_scene_find_source(scene, sceneitem_name) : NULL;
+		scene ? obs_scene_find_source_recursive(scene, sceneitem_name) : NULL;
 	if (audio_move->sceneitem &&
 	    obs_source_removed(
 		    obs_sceneitem_get_source(audio_move->sceneitem))) {
@@ -314,6 +316,7 @@ void audio_move_update(void *data, obs_data_t *settings)
 		}
 	}
 	if (target_source && obs_source_removed(target_source)) {
+		obs_source_release(target_source);
 		target_source = NULL;
 	}
 	if (target_source) {
@@ -415,8 +418,31 @@ static bool add_source_to_prop_list(void *data, obs_source_t *source)
 {
 	obs_property_t *p = (obs_property_t *)data;
 	const char *name = obs_source_get_name(source);
-	if (name && strlen(name))
-		obs_property_list_add_string(p, name, name);
+	if (!name || !strlen(name))
+		return true;
+	size_t count = obs_property_list_item_count(p);
+	size_t idx = 0;
+	while (idx < count &&
+	       strcmp(name, obs_property_list_item_string(p, idx)) > 0)
+		idx++;
+	obs_property_list_insert_string(p, idx, name, name);
+	return true;
+}
+
+static bool add_group_to_prop_list(void *data, obs_source_t *source)
+{
+	obs_property_t *p = (obs_property_t *)data;
+	if (!obs_source_is_group(source))
+		return true;
+	const char *name = obs_source_get_name(source);
+	if (!name || !strlen(name))
+		return true;
+	size_t count = obs_property_list_item_count(p);
+	size_t idx = 0;
+	while (idx < count &&
+	       strcmp(name, obs_property_list_item_string(p, idx)) > 0)
+		idx++;
+	obs_property_list_insert_string(p, idx, name, name);
 	return true;
 }
 
@@ -432,6 +458,7 @@ static bool audio_move_action_changed(obs_properties_t *props,
 	    action == VALUE_ACTION_SOURCE_VISIBILITY) {
 		obs_property_list_clear(scene);
 		obs_enum_scenes(add_source_to_prop_list, scene);
+		obs_enum_sources(add_group_to_prop_list, scene);
 		obs_property_set_visible(scene, true);
 		obs_property_set_visible(sceneitem, true);
 	} else {
@@ -511,6 +538,8 @@ static bool audio_move_scene_changed(void *data, obs_properties_t *props,
 	obs_source_t *source = obs_get_source_by_name(scene_name);
 	obs_source_release(source);
 	obs_scene_t *scene = obs_scene_from_source(source);
+	if (!scene)
+		scene = obs_group_from_source(source);
 	if (!scene)
 		return true;
 	obs_scene_enum_items(scene, add_sceneitem_to_prop_list, sceneitem);
@@ -941,6 +970,53 @@ void audio_move_tick(void *data, float seconds)
 		obs_source_release(source);
 	}
 }
+
+void audio_move_remove(void *data, obs_source_t *source) {
+	UNUSED_PARAMETER(source);
+	struct audio_move_info *audio_move = data;
+	if (audio_move->target_source) {
+		obs_source_t *source =
+			obs_weak_source_get_source(audio_move->target_source);
+		signal_handler_t *sh = obs_source_get_signal_handler(source);
+		signal_handler_disconnect(sh, "remove",
+					  audio_move_source_remove, audio_move);
+		signal_handler_disconnect(
+			sh, "destroy", audio_move_source_destroy, audio_move);
+		obs_source_release(source);
+		obs_weak_source_release(audio_move->target_source);
+	}
+	audio_move->target_source = NULL;
+	if (audio_move->sceneitem) {
+		obs_scene_t *scene =
+			obs_sceneitem_get_scene(audio_move->sceneitem);
+		signal_handler_t *sh = obs_source_get_signal_handler(
+			obs_scene_get_source(scene));
+		if (sh) {
+			signal_handler_disconnect(sh, "item_remove",
+						  audio_move_item_remove,
+						  audio_move);
+			signal_handler_disconnect(sh, "remove",
+						  audio_move_source_remove,
+						  audio_move);
+			signal_handler_disconnect(sh, "destroy",
+						  audio_move_source_destroy,
+						  audio_move);
+		}
+		obs_source_t *item_source =
+			obs_sceneitem_get_source(audio_move->sceneitem);
+		if (item_source) {
+			sh = obs_source_get_signal_handler(item_source);
+			signal_handler_disconnect(sh, "remove",
+						  audio_move_source_remove,
+						  audio_move);
+			signal_handler_disconnect(sh, "destroy",
+						  audio_move_source_destroy,
+						  audio_move);
+		}
+	}
+	audio_move->sceneitem = NULL;
+}
+
 struct obs_source_info audio_move_filter = {
 	.id = AUDIO_MOVE_FILTER_ID,
 	.type = OBS_SOURCE_TYPE_FILTER,
@@ -953,4 +1029,5 @@ struct obs_source_info audio_move_filter = {
 	.update = audio_move_update,
 	.load = audio_move_update,
 	.video_tick = audio_move_tick,
+	.filter_remove = audio_move_remove,
 };
